/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker;

import org.hedgecode.snooker.api.SnookerScoreAPI;
import org.hedgecode.snooker.cache.CacheSnookerScore;
import org.hedgecode.snooker.json.JsonSnookerScore;

/**
 * Snooker Score Common Class for API access.
 *
 * @author Dmitry Samoshin aka gotty
 */
public final class Snooker {

    private static final SnookerScoreAPI JSON_API = JsonSnookerScore.getInstance();
    private static final SnookerScoreAPI CACHED_API = CacheSnookerScore.getInstance();

    public static SnookerScoreAPI API() {
        return CACHED_API;
    }

    public static SnookerScoreAPI API(boolean useCache) {
        return useCache ? CACHED_API : JSON_API;
    }

    public static SnookerScoreAPI uncachedAPI() {
        return JSON_API;
    }

    public static SnookerScoreAPI cachedAPI() {
        return CACHED_API;
    }

}
