/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

/**
 * Snooker Score properties holder.
 *
 * @author Dmitry Samoshin aka gotty
 */
public final class SnookerScoreProperties {

    /** Properties file. */
    private static final String PROPERTIES_FILE = "snooker.properties";

    /** Properties. */
    private static final Properties PROPERTIES;

    /**
     * Static properties initialization.
     */
    static {
        PROPERTIES = new Properties();
        readProperties(PROPERTIES_FILE, PROPERTIES, true);
    }

    /**
     * @param propsFile Properties file name.
     * @param props Properties.
     * @param throwExc Flag indicating whether to throw an exception or not.
     */
    public static void readProperties(String propsFile, Properties props, boolean throwExc) {
        try (InputStream is = SnookerScoreProperties.class.getClassLoader().getResourceAsStream(propsFile)) {
            if (is == null) {
                if (throwExc)
                    throw new RuntimeException("Failed to find properties file: " + propsFile);
                else
                    return;
            }

            props.load(is);
        }
        catch (IOException e) {
            throw new RuntimeException("Failed to read properties file: " + propsFile, e);
        }
    }

    /**
     * Empty string for not found properties.
     */
    private static final String EMPTY = "";

    /**
     * Gets property value.
     *
     * @param key Property key.
     * @return Property value (possibly empty string, but never {@code null}).
     */
    public static String get(String key) {
        return PROPERTIES.getProperty(key, EMPTY);
    }

    /**
     * Private constructor.
     */
    private SnookerScoreProperties() {
    }

}
