/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.api;

import java.awt.image.BufferedImage;
import java.io.Serializable;
import java.net.URL;

import org.hedgecode.snooker.SnookerURLUtils;

/**
 * Player Image Storage Entity.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class PlayerImage implements Serializable {

    private URL url;
    private BufferedImage image;

    public PlayerImage(URL imageUrl) {
        url = imageUrl;
    }

    public PlayerImage(URL imageUrl, boolean autoload) throws APIException {
        url = imageUrl;
        if (autoload) loadImage();
    }

    public URL url() {
        return url;
    }

    public String urlString() {
        return url.toString();
    }

    public BufferedImage image() {
        return image;
    }

    public BufferedImage loadImage() throws APIException {
        image = SnookerURLUtils.loadImage(url);
        return image;
    }

    @Override
    public String toString() {
        return urlString();
    }

}
