/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.request;

/**
 * Requester of Player Money Rankings.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class RankingRequester extends AbstractRequester {

    private static final String RANKING_URL =
            API_SNOOKER_URL + "?rt=[RankingType]&s=[Season]";

    private static final Requester _instance = new RankingRequester();

    private RankingRequester() {
    }

    public static Requester getInstance() {
        return _instance;
    }

    @Override
    protected String getRequestUrl(int id) throws RequestException {
        throw new RequestException(RANKING_URL, "Incorrect Ranking Params");
    }

    @Override
    protected String getRequestUrl(RequestParams params) throws RequestException {
        if (params == null
                || params.getRankingType() == null
                || params.getSeason() == null)
            throw new RequestException(RANKING_URL, "Incorrect Ranking Params");

        return RANKING_URL.replace(
                "[RankingType]", params.getRankingType().name()
        ).replace(
                "[Season]", String.valueOf(params.getSeason().getYear())
        );
    }

}
